from .cccccc import DDDDDD
from os import get_terminal_size


def EEEEEE():
    WIDTH = get_terminal_size()[0]
    print("恭喜发财恭喜发财".center(WIDTH - 8, "="))
    DDDDDD().say_hello()


if __name__ == "__main__":
    EEEEEE()
